#!/bin/sh

set -euo pipefail

for IDX in $(printenv | grep -E '^PG_DB_([0-9]+)=' | sed -E 's/^PG_DB_([0-9]+)=.*/\1/'); do
  DB_NAME=$(printenv PG_DB_${IDX})
  echo "Found DB ${DB_NAME} to create"
  DB_OWNER=$(printenv PG_DB_${IDX}_OWNER || echo "${DB_NAME}")
  DB_ENCODING=$(printenv PG_DB_${IDX}_ENCODING || echo "UTF8")
  DB_TEMPLATE=$(printenv PG_DB_${IDX}_TEMPLATE || echo "")
  DB_LOCALE=$(printenv PG_DB_${IDX}_LOCALE || echo "${LANG}")
  DB_EXTENSIONS=$(printenv PG_DB_${IDX}_EXTENSIONS || echo "")
  if [ "${LDAP2PG_MODE}" = "real" ]; then
    echo "Create postgres role ${DB_OWNER} if needed"
    psql <<_EOSQL
      SELECT 'CREATE ROLE "${DB_OWNER}"'
        WHERE NOT EXISTS (SELECT FROM pg_catalog.pg_roles WHERE rolname = '${DB_OWNER}')\gexec
_EOSQL
    TEMPLATE=""
    if [ "${DB_TEMPLATE}" != "" ]; then
      TEMPLATE="TEMPLATE ${DB_TEMPLATE}"
    fi
    echo "Create postgres database ${DB_NAME} (OWNER \"${DB_OWNER}\" ENCODING \"${DB_ENCODING}\" LOCALE \"${DB_LOCALE}\" ${TEMPLATE}) if needed"
    psql <<_EOSQL
      SELECT 'CREATE DATABASE "${DB_NAME}" OWNER "${DB_OWNER}" ENCODING "${DB_ENCODING}" LOCALE "${DB_LOCALE}" ${TEMPLATE}'
        WHERE NOT EXISTS (SELECT FROM pg_database WHERE datname = '${DB_NAME}')\gexec
_EOSQL
    psql -d ${DB_NAME} <<_EOSQL
      ALTER DEFAULT PRIVILEGES IN SCHEMA public GRANT ALL ON FUNCTIONS TO pg_database_owner;
      ALTER SCHEMA public OWNER TO "${DB_OWNER}";
_EOSQL
    if [ -n "${DB_EXTENSIONS}" ]; then
      for EXT in $(echo ${DB_EXTENSIONS} | sed -e 's/,/\n/g'); do
        psql -d ${DB_NAME} <<_EOSQL
          CREATE EXTENSION IF NOT EXISTS "${EXT}";
_EOSQL
      done
    fi
  else
    echo "Would create user ${DB_OWNER} and database ${DB_NAME} (OWNER \"${DB_OWNER}\" ENCODING \"${DB_ENCODING}\" LOCALE \"${DB_LOCALE}\"), but we're running in dry mode"
  fi
done

